@@ -1,33 +1,32 @@
 package Graphics::Primitive::ComponentList;
 use Moose;
-use MooseX::AttributeHelpers;
 use MooseX::Storage;
 
 with Storage (format => 'JSON', io => 'File');
 
 has 'components' => (
-    metaclass => 'Collection::Array',
+    traits => ['Array'],
     is => 'rw',
     isa => 'ArrayRef',
     default => sub { [] },
-    provides => {
-        'count'=> 'component_count',
-        'get' => 'get_component',
-        'push' => 'push_components',
-        'set'=> 'set_component'
+    handles => {
+        'component_count' => 'count',
+        'get_component' => 'get',
+        'push_components' => 'push',
+        'set_component' => 'set',
     },
 );
 
 has 'constraints' => (
-    metaclass => 'Collection::Array',
+    traits => ['Array'],
     is => 'rw',
     isa => 'ArrayRef',
     default => sub { [] },
-    provides => {
-        'count'=> 'constraint_count',
-        'get' => 'get_constraint',
-        'push' => 'push_constraints',
-        'set' => 'set_constraint'
+    handles => {
+        'constraint_count' => 'count',
+        'get_constraint' => 'get',
+        'push_constraints' => 'push',
+        'set_constraint' => 'set',
     },
 );
 
@@ -254,4 +253,4 @@ automatically be notified of progress on your bug as I make changes.
 Copyright 2008-2009 by Cory G Watson.
 
 This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
\ No newline at end of file
+under the same terms as Perl itself.
